# coding: utf-8

"""
    Stencila Hub API

    ## Authentication  Many endpoints in the Stencila Hub API require an authentication token. These tokens carry many privileges, so be sure to keep them secure. Do not place your tokens in publicly accessible areas such as client-side code. The API is only served over HTTPS to avoid exposing tokens and other data on the network.  To obtain a token, [`POST /api/tokens`](#operations-tokens-tokens_create) with either a `username` and `password` pair, or an [OpenID Connect](https://openid.net/connect/) token. Then use the token in the `Authorization` header of subsequent requests with the prefix `Token` e.g.      curl -H \"Authorization: Token 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34\" https://hub.stenci.la/api/projects/  Alternatively, you can use `Basic` authentication with the token used as the username and no password. This can be more convenient when using command line tools such as [cURL](https://curl.haxx.se/) e.g.      curl -u 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  Or, the less ubiquitous, but more accessible [httpie](https://httpie.org/):      http --auth 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  In both examples above, the trailing colon is not required but avoids being asked for a password.  ## Versioning  The Stencila Hub is released using semantic versioning. The current version is available from the [`GET /api/status`](/api/status) endpoint. Please see the [Github release page](https://github.com/stencila/hub/releases) and the [changelog](https://github.com/stencila/hub/blob/master/CHANGELOG.md) for details on each release. We currently do not provide versioning of the API but plan to do so soon (probably by using a `Accept: application/vnd.stencila.hub+json;version=1.0` request header). If you are using, or interested in using, the API please contact us and we may be able to expedite this.   # noqa: E501

    The version of the OpenAPI document: v1
    Contact: hello@stenci.la
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from stencila.hub.configuration import Configuration


class ProjectAgentUpdate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'role': 'str',
        'project': 'int',
        'user': 'int',
        'team': 'int'
    }

    attribute_map = {
        'id': 'id',
        'role': 'role',
        'project': 'project',
        'user': 'user',
        'team': 'team'
    }

    def __init__(self, id=None, role=None, project=None, user=None, team=None, local_vars_configuration=None):  # noqa: E501
        """ProjectAgentUpdate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._role = None
        self._project = None
        self._user = None
        self._team = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.role = role
        if project is not None:
            self.project = project
        if user is not None:
            self.user = user
        if team is not None:
            self.team = team

    @property
    def id(self):
        """Gets the id of this ProjectAgentUpdate.  # noqa: E501


        :return: The id of this ProjectAgentUpdate.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProjectAgentUpdate.


        :param id: The id of this ProjectAgentUpdate.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def role(self):
        """Gets the role of this ProjectAgentUpdate.  # noqa: E501

        Role the user or team has within the project.  # noqa: E501

        :return: The role of this ProjectAgentUpdate.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this ProjectAgentUpdate.

        Role the user or team has within the project.  # noqa: E501

        :param role: The role of this ProjectAgentUpdate.  # noqa: E501
        :type role: str
        """
        if self.local_vars_configuration.client_side_validation and role is None:  # noqa: E501
            raise ValueError("Invalid value for `role`, must not be `None`")  # noqa: E501
        allowed_values = ["READER", "REVIEWER", "EDITOR", "AUTHOR", "MANAGER", "OWNER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and role not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `role` ({0}), must be one of {1}"  # noqa: E501
                .format(role, allowed_values)
            )

        self._role = role

    @property
    def project(self):
        """Gets the project of this ProjectAgentUpdate.  # noqa: E501

        Project to which the user or team is being given access to.  # noqa: E501

        :return: The project of this ProjectAgentUpdate.  # noqa: E501
        :rtype: int
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this ProjectAgentUpdate.

        Project to which the user or team is being given access to.  # noqa: E501

        :param project: The project of this ProjectAgentUpdate.  # noqa: E501
        :type project: int
        """

        self._project = project

    @property
    def user(self):
        """Gets the user of this ProjectAgentUpdate.  # noqa: E501

        A user given access to the project.  # noqa: E501

        :return: The user of this ProjectAgentUpdate.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this ProjectAgentUpdate.

        A user given access to the project.  # noqa: E501

        :param user: The user of this ProjectAgentUpdate.  # noqa: E501
        :type user: int
        """

        self._user = user

    @property
    def team(self):
        """Gets the team of this ProjectAgentUpdate.  # noqa: E501

        A team given access to the project.  # noqa: E501

        :return: The team of this ProjectAgentUpdate.  # noqa: E501
        :rtype: int
        """
        return self._team

    @team.setter
    def team(self, team):
        """Sets the team of this ProjectAgentUpdate.

        A team given access to the project.  # noqa: E501

        :param team: The team of this ProjectAgentUpdate.  # noqa: E501
        :type team: int
        """

        self._team = team

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectAgentUpdate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProjectAgentUpdate):
            return True

        return self.to_dict() != other.to_dict()
